@@ -45,6 +45,11 @@ func init() {
 		DownloadCmd.PersistentFlags().MarkHidden("white-list")
 		DownloadCmd.PersistentFlags().MarkHidden("black-list")
 		DownloadCmd.PersistentFlags().MarkHidden("model")
+		DownloadCmd.PersistentFlags().MarkHidden("confirm")
+		DownloadCmd.PersistentFlags().MarkHidden("skip-all")
+		DownloadCmd.PersistentFlags().MarkHidden("resume-all")
+		DownloadCmd.PersistentFlags().MarkHidden("restart-all")
+		DownloadCmd.PersistentFlags().MarkHidden("remove-commas")
 		c.Parent().HelpFunc()(c, s)
 	})
 	// viper.BindPFlag("download.keys.beta", downloadKeysCmd.Flags().Lookup("beta"))
