@@ -11,6 +11,9 @@ import (
 	"time"
 
 	"github.com/apex/log"
+	"github.com/blacktop/go-apfs/pkg/disk/dmg"
+	"github.com/blacktop/ipsw/internal/download"
+	"github.com/blacktop/ipsw/internal/magic"
 	"github.com/blacktop/ipsw/internal/utils"
 	"github.com/blacktop/ipsw/pkg/aea"
 	"github.com/blacktop/ipsw/pkg/info"
@@ -42,7 +45,7 @@ func (c Context) Unmount() error {
 }
 
 // DmgInIPSW will mount a DMG from an IPSW
-func DmgInIPSW(path, typ, pemDbPath string) (*Context, error) {
+func DmgInIPSW(path, typ, pemDbPath string, keys any) (*Context, error) {
 	ipswPath := filepath.Clean(path)
 
 	i, err := info.Parse(ipswPath)
@@ -110,6 +113,39 @@ func DmgInIPSW(path, typ, pemDbPath string) (*Context, error) {
 			return nil, fmt.Errorf("failed to parse AEA encrypted DMG: %v", err)
 		}
 	}
+	if isEncrypted, err := magic.IsEncryptedDMG(extractedDMG); err != nil {
+		return nil, fmt.Errorf("failed to check if DMG is encrypted: %v", err)
+	} else if isEncrypted {
+		var key string
+		switch v := keys.(type) {
+		case string:
+			key = v
+		case map[string]download.WikiFWKeys:
+			if len(v) == 0 {
+				return nil, fmt.Errorf("DMG is encrypted, please provide a key")
+			}
+			for _, wk := range v {
+				if strings.EqualFold(wk.Filename[0], filepath.Base(extractedDMG)) {
+					key = wk.Key[0]
+					break
+				}
+			}
+			if key == "" {
+				return nil, fmt.Errorf("key not found for DMG '%s' in theapplewiki lookup results", extractedDMG)
+			}
+		}
+		log.Info("Decrypting DMG...")
+		if dmg, err := dmg.Open(extractedDMG, &dmg.Config{
+			Key: key,
+		}); err != nil {
+			return nil, fmt.Errorf("failed to open DMG '%s': %v", extractedDMG, err)
+		} else {
+			defer dmg.Close()
+			if err := os.Rename(dmg.DecryptedTemp(), extractedDMG); err != nil {
+				return nil, fmt.Errorf("failed to overwrite encrypted DMG with the decrypted one: %v", err)
+			}
+		}
+	}
 
 	mp, am, err := utils.MountDMG(extractedDMG)
 	if err != nil {
