@@ -31,8 +31,9 @@ import (
 // CREDIT - https://github.com/majd/ipatool
 
 const (
-	appStoreAuthURL     = "https://buy.itunes.apple.com/WebObjects/MZFinance.woa/wa/authenticate"
-	appStoreDownloadURL = "https://buy.itunes.apple.com/WebObjects/MZFinance.woa/wa/volumeStoreDownloadProduct"
+	appStoreAuthURL = "https://buy.itunes.apple.com/WebObjects/MZFinance.woa/wa/authenticate"
+	// appStoreDownloadURL = "https://buy.itunes.apple.com/WebObjects/MZFinance.woa/wa/volumeStoreDownloadProduct"
+	appStoreDownloadURL = "https://downloaddispatch.itunes.apple.com/WebObjects/DownloadDispatch.woa/wa/ent/download?guid="
 	appStorePurchaseURL = "https://buy.itunes.apple.com/WebObjects/MZFinance.woa/wa/buyProduct"
 	appStoreSearchURL   = "https://itunes.apple.com/search"
 	appStoreLookupURL   = "https://itunes.apple.com/lookup"
@@ -65,6 +66,7 @@ type AppStoreConfig struct {
 	StoreFront    string
 	VaultPassword string
 	ConfigDir     string
+	KeybagPlist   string
 }
 
 type AppStore struct {
@@ -181,13 +183,21 @@ type purchaseResponse struct {
 }
 
 type downloadRequest struct {
-	GUID              string `plist:"guid,omitempty"`
-	Price             string `plist:"price,omitempty"`
-	PricingParameters string `plist:"pricingParameters,omitempty"`
-	ProductType       string `plist:"productType,omitempty"`
-	SalableAdamId     string `plist:"salableAdamId,omitempty"`
+	CreditDisplay string `plist:"creditDisplay,omitempty"`
+	GUID          string `plist:"guid,omitempty"`
+	KBSync        string `plist:"kbsync,omitempty"`
+	SalableAdamId string `plist:"salableAdamId,omitempty"`
+	SerialNumber  string `plist:"serialNumber,omitempty"`
 }
 
+// type downloadRequest struct {
+// 	GUID              string `plist:"guid,omitempty"`
+// 	Price             string `plist:"price,omitempty"`
+// 	PricingParameters string `plist:"pricingParameters,omitempty"`
+// 	ProductType       string `plist:"productType,omitempty"`
+// 	SalableAdamId     string `plist:"salableAdamId,omitempty"`
+// }
+
 type downloadResponse struct {
 	FailureType     string              `plist:"failureType,omitempty"`
 	CustomerMessage string              `plist:"customerMessage,omitempty"`
@@ -740,18 +750,35 @@ func (as *AppStore) Download(bundleID, output string) error {
 	if err != nil {
 		return fmt.Errorf("failed to get mac address: %v", err)
 	}
-
 	guid := strings.ReplaceAll(strings.ToUpper(mac), ":", "")
 
-	plist.NewEncoderForFormat(buf, plist.XMLFormat).Encode(&downloadRequest{
-		GUID:              guid,
-		Price:             "0",
-		PricingParameters: "STDRDL",
-		ProductType:       "C",
-		SalableAdamId:     strconv.Itoa(app.ID),
-	})
+	if as.config.KeybagPlist != "" {
+		keybag, err := os.ReadFile(as.config.KeybagPlist)
+		if err != nil {
+			return fmt.Errorf("failed to read keybag plist '%s': %v", as.config.KeybagPlist, err)
+		}
+		var dlReq downloadRequest
+		if err := plist.NewDecoder(bytes.NewReader(keybag)).Decode(&dlReq); err != nil {
+			return fmt.Errorf("failed to decode keybag plist '%s': %v", as.config.KeybagPlist, err)
+		}
+		guid = dlReq.GUID
+		plist.NewEncoderForFormat(buf, plist.XMLFormat).Encode(&downloadRequest{
+			GUID:          dlReq.GUID,
+			KBSync:        dlReq.KBSync,
+			SalableAdamId: strconv.Itoa(app.ID),
+			SerialNumber:  dlReq.SerialNumber,
+		})
+	} else {
+		plist.NewEncoderForFormat(buf, plist.XMLFormat).Encode(&downloadRequest{
+			CreditDisplay: "$0.00",
+			GUID:          guid,
+			KBSync:        "0",
+			SalableAdamId: strconv.Itoa(app.ID),
+			SerialNumber:  "0",
+		})
+	}
 
-	req, err := http.NewRequest("POST", appStoreDownloadURL, buf)
+	req, err := http.NewRequest("POST", appStoreDownloadURL+guid, buf)
 	if err != nil {
 		return fmt.Errorf("failed to create http POST request: %v", err)
 	}
